## 更新日志
- 2025-11-12
  - 单Agent改为多Agent模式，规划、执行、反思各司其职，指令格式也可以更随意
  - 单个Agent只执行1到2个操作，有效降低长路径操作的模型幻觉问题，更长的操作路径也能保持稳定
  - 优化与模型的数据交换轮次，进一步降低Token消耗，同时提高执行效率
  - 优化步骤执行过程，执行顺序不再出现错乱、丢失、无屏幕截图情况
  - 增加模型断言，未找到对应元素时自动标记失败，不再返回一个错误的元素
  - 解决模型同时调用多个工具导致执行错误的问题
  - 支持等待直到xx元素出现、上下左右滑动直到xx出现等动态判断操作
  - 支持点击元素的相对位置，如点击"xx"按钮左侧1/3处、底部、顶部、左侧、右侧等，作为部分元素点击中心位置不符合预期的兜底
  - WebAgent支持点击xx，上传文件: path/url 操作
  - 更清晰简洁的日志打印，可以开启debug模式查看更多

- 2025-10-08
  - 优化步骤报告样式
  - 支持移动端通过自然语言打开任意 APP

- 2025-09-03
  - 支持等待、停留等自然语言操作
  - 支持传递 OmniParser Key 鉴权
  - 断言支持判断页面/屏幕中是否存在某个关键字

- 2025-08-01
  
  - 精简了系统提示词，每次调用使用更少的token
  - 优化报告的记录和生成逻辑，解决步骤偶然错乱的问题
  - 优化工具的参数，实现最小化参数，减少token
  - 优化了等待逻辑，实现更精准的等待，不需要统一等待1s
  - 截图、解析改成异步,并发不阻塞
  - 优化浏览器配置，支持使用持久化缓存，二次启动页面速度更快

- 2025-07-28
  
  - 增加滚动和滑动操作
  - 支持H5 swiper 组件滑动

- 2025-06-25
  
  - 优化 LLM Graph 控制
  - 更新配置模式

- 2025-06-09
  
  - 支持 Web Agent 模式
  - 增加执行报告和过程实时渲染
  - 重构同步方法为异步

- 2025-06-04
  
  - 支持移动端 Agent 模式
  - 增加`click` `input` `open_url` 工具
  - 支持接入 OmniParser 进行元素解析